ServerConfig

Struct ServerConfig 

pub struct ServerConfig<ServerSpecific> {
    pub port: u16,
    pub ips: Box<[IpAddr]>,
    pub bind_to: Skip,
    pub self_check_code: Option<String>,
    pub jwt_key: Option<SigningKey>,
    pub enc_key: Option<PrivateKey>,
    pub admin_key: Option<VerifyingKey>,
    pub object_store: Option<ObjectStoreConfig>,
    pub version: Option<String>,
    extra: ServerSpecific,
}
Configuration for one server. Derefs to ServerSpecific..

Fields

port: u16

Port to bind this server to

ips: Box<[IpAddr]>

Ip addresses to bind to

bind_to: Skip

Deprecated.

self_check_code: Option<String>

Random string used by this server to identify itself. Randomly generated if not set. May be set manually when multiple instances of the same server are used.

jwt_key: Option<SigningKey>

Key used to sign JSON web tokens generated by this server. If None, one is generated automatically (which is not suitable for production.)

Generate using cargo run tools generate signing-key.

enc_key: Option<PrivateKey>

Each server advertises an elgamal::PublicKey so that shared secrets may be established with this server, and also encrypted messages may be sent to it.

This key is also used to derive non-permanent secrets, like the the transcryptor’s encryption factor f_H for a hub H.

Generate using cargo run tools generate scalar.

admin_key: Option<VerifyingKey>

Key used by admin to sign requests for the admin endpoints. If None, one is generated automatically and the private key is printed to the log.

object_store: Option<ObjectStoreConfig>

If the server needs an object store, use this one.

version: Option<String>

What version (if any) to claim this pubhubs binary is running. Uses crate::servers::version() by default. Should only be used for troubleshooting/debugging.

extra: ServerSpecific

Can be accessed via Deref.