pub struct Config {
pub phc_url: UrlPwa,
pub log: Option<LogConfig>,
pub(crate) preparation_state: PreparationState,
pub host_aliases: HostAliases,
pub wd: PathBuf,
pub phc: Option<ServerConfig<ExtraConfig>>,
pub transcryptor: Option<ServerConfig<ExtraConfig>>,
pub auths: Option<ServerConfig<ExtraConfig>>,
}Expand description
Configuration for one, or several, of the PubHubs servers
Also used for the pubhubs admin cli command. In that case only phc_url needs to be set.
Fields
phc_url: UrlPwaURL of the PubHubs Central server.
Any information on the other servers that can be stored at PHC is stored at PHC.
log: Option<LogConfig>Configure logging. Overwrites what’s passed through RUST_LOG.
preparation_state: PreparationStatehost_aliases: HostAliasesSpecify abbreviations for an IP address that are only valid in this configuration file.
Any UrlPwa that contains one of the aliases as host name exactly (so no subdomain) will be modified to have as host name the associated IP address.
wd: PathBufPath with respect to which relative paths are interpretted.
phc: Option<ServerConfig<ExtraConfig>>Configuration to run PubHubs Central
transcryptor: Option<ServerConfig<ExtraConfig>>Configuration to run the Transcryptor
auths: Option<ServerConfig<ExtraConfig>>Configuration to run the Authentication Server
Implementations
Sourceimpl Config
impl Config
Sourcepub fn load_from_path(path: &Path) -> Result<Option<Self>>
pub fn load_from_path(path: &Path) -> Result<Option<Self>>
pub fn preliminary_prep(&mut self) -> Result<()>
Sourcepub async fn prepare_for(&self, server: Name) -> Result<Self>
pub async fn prepare_for(&self, server: Name) -> Result<Self>
Clones this configuration and strips out everything that’s not needed to run the specified server. Also generated any random values not yet set.